import React from 'react'

import { trigger } from '../util/ReactCSP'

export class Layout extends React.Component {
  constructor(props) {
    super(props)

    this.state = { scroll: 0 }

    this.handleScroll = this.handleScroll.bind(this)
  }

  componentDidMount() {
    if (this.props.chan) {
      this.props.chan(trigger.component(this, (prevProps, prevState) => {
        if (this.state.scroll !== prevState.scroll) {
          return {path: `react-layer-layout.layout/${this.props.label}`, type: 'data', preload: { scroll: this.state.scroll}}
        }
      }))
    }
  }

  handleScroll(evt) {
    this.setState({ scroll: evt.target.scrollTop })
  }

  render() {
    return (
      <div 
        className={`place-${this.props.label} ${this.props.external}`}
        onScroll={this.handleScroll}
        style={{
          position: 'absolute', 
          top: this.props.top, 
          left: this.props.left,
          width: this.props.width,
          height: this.props.height,
          overflow: this.props.overflow,
          zIndex: this.props.zIndex,
        }}
      >
        {this.props.children}
      </div>
    )
  }
}

Layout.propTypes = {
  external: React.PropTypes.string,
  top: React.PropTypes.number,
  left: React.PropTypes.number,
  overflow: React.PropTypes.string,
  zIndex: React.PropTypes.number,
  chan: React.PropTypes.func,
  width: React.PropTypes.number.isRequired,
  height: React.PropTypes.number.isRequired,
  label: React.PropTypes.string.isRequired,
}

Layout.defaultProps = {
  top: 0,
  left: 0,
  overflow: 'inherit',
  zIndex: 0,
}
