import React from 'react'
import _ from 'lodash'

export class TextBase extends React.Component {
  render() {
    const inline = this.props.inline || {}
    const eventFunc = this.props.eventFunc || {}

    if (this.props.block) inline.display = 'inline-block'
    if (this.props.nowrap) inline.whiteSpace = 'nowrap'
    if (this.props.pre) inline.whiteSpace = 'pre-wrap'
    if (this.props.pre && this.props.nowrap) inline.whiteSpace = 'pre'

    return (
      <span 
        className={this.props.external}
        style={inline}
        { ...eventFunc }
      > 
        { this.props.children }
      </span>
    )
  }
}

TextBase.propTypes = {
  external: React.PropTypes.string,
  inline: React.PropTypes.object,
  eventFunc: React.PropTypes.object,
  nowrap: React.PropTypes.bool,
  block: React.PropTypes.bool,
  pre: React.PropTypes.bool,
}

TextBase.defaultProps = {
  external: null,
  block: false,
  nowrap: false,
  pre: false,
}

const Phrase = ({size='14px', color='#414141', align ='left', weight='normal', decoration='none', inline={}, ...props}) => {
  inline.lineHeight = 1
  inline.fontSize = size
  inline.fontWeight = weight
  inline.decoration = decoration
  inline.color = color
  inline.textAlign = align

  return (<TextBase inline={inline} {...props} />)
}

const Message = ({size='14px', color='#414141', weight='normal', align="left", line="1.7", width="auto", inline={}, ...props}) => {
  inline.lineHeight = 1
  inline.fontSize = size
  inline.fontWeight = weight
  inline.lineHeight = line
  inline.color = color
  inline.textAlign = align
  inline.width = width

  return (<TextBase inline={inline} {...props} />) 
}

const Article = () => {
  // Markdown, JSON render
}

export { Phrase, Message, Article }
